==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.AnyFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Any;
import java.lang.Deprecated;
import javax.validation.Valid;
import me.snowdrop.istio.api.AnyBuilder;
import java.lang.Boolean;

public interface BypassSpecFluent<A extends BypassSpecFluent<A>> extends Fluent<A>{


    public String getBackendAddress();
    public A withBackendAddress(String backendAddress);
    public Boolean hasBackendAddress();
    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public Any getParams();
    public Any buildParams();
    public A withParams(Any params);
    public Boolean hasParams();
    public A withNewParams(String typeUrl,String value);
    public BypassSpecFluent.ParamsNested<A> withNewParams();
    public BypassSpecFluent.ParamsNested<A> withNewParamsLike(Any item);
    public BypassSpecFluent.ParamsNested<A> editParams();
    public BypassSpecFluent.ParamsNested<A> editOrNewParams();
    public BypassSpecFluent.ParamsNested<A> editOrNewParamsLike(Any item);
    public Boolean isSessionBased();
    public A withSessionBased(Boolean sessionBased);
    public Boolean hasSessionBased();
    public A withNewSessionBased(String arg1);
    public A withNewSessionBased(boolean arg1);

    public interface ParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AnyFluent<BypassSpecFluent.ParamsNested<N>>{

        
    public N and();    public N endParams();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.AnyFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Any;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import me.snowdrop.istio.api.AnyBuilder;
import java.lang.Boolean;

public interface BypassSpecFluent<A extends BypassSpecFluent<A>> extends Fluent<A>{


    public String getBackendAddress();
    public A withBackendAddress(String backendAddress);
    public Boolean hasBackendAddress();
    public A withNewBackendAddress(String arg1);
    public A withNewBackendAddress(StringBuilder arg1);
    public A withNewBackendAddress(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public Any getParams();
    public Any buildParams();
    public A withParams(Any params);
    public Boolean hasParams();
    public A withNewParams(String typeUrl,String value);
    public BypassSpecFluent.ParamsNested<A> withNewParams();
    public BypassSpecFluent.ParamsNested<A> withNewParamsLike(Any item);
    public BypassSpecFluent.ParamsNested<A> editParams();
    public BypassSpecFluent.ParamsNested<A> editOrNewParams();
    public BypassSpecFluent.ParamsNested<A> editOrNewParamsLike(Any item);
    public Boolean isSessionBased();
    public A withSessionBased(Boolean sessionBased);
    public Boolean hasSessionBased();
    public A withNewSessionBased(String arg1);
    public A withNewSessionBased(boolean arg1);

    public interface ParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AnyFluent<BypassSpecFluent.ParamsNested<N>>{

        
    public N and();    public N endParams();
}


}
